<?php

namespace Drupal\store_visibility_condition\Plugin\Condition;

use Drupal\Core\Condition\ConditionPluginBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\commerce_store\CurrentStoreInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @Condition(
 *   id = "store_visibility",
 *   label = @Translation("Commerce Store Visibility"),
 *   summary = @Translation("Not restricted"),
 *   context_definitions = {
 *     "commerce_store" = @ContextDefinition("entity:commerce_store",
 *       label = @Translation("Store"),
 *       required = FALSE
 *     )
 *   }
 * )
 */
class StoreVisibilityCondition extends ConditionPluginBase {

  protected $currentStore;

  // Constructeur modifié
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    CurrentStoreInterface $current_store
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentStore = $current_store ?: \Drupal::service('commerce_store.current_store');
  }

  // Méthode create simplifiée
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('commerce_store.current_store')
    );
  }

  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $stores = \Drupal::entityTypeManager()->getStorage('commerce_store')->loadMultiple();
    
    $options = [];
    foreach ($stores as $store) {
      $options[$store->id()] = $store->label();
    }

    $form['stores'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Visible on these stores'),
      '#description' => $this->t('Leave blank for no restrictions'),
      '#options' => $options,
      '#default_value' => $this->configuration['stores'] ?? [],
    ];

    // Attached library to summarize configuration settings.
    //$form['#attached']['library'][] = 'store_visibility_condition/summary';

    return parent::buildConfigurationForm($form, $form_state);
  }

  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['stores'] = array_filter($form_state->getValue('stores'));
    parent::submitConfigurationForm($form, $form_state);
  }

  public function evaluate() {
    $current_store = $this->currentStore->getStore();
  
    if (empty($this->configuration['stores'])) {
      return TRUE; // Aucune restriction si aucun store sélectionné
    }

    return in_array($current_store->id(), $this->configuration['stores']);
  }

  public function summary() {
    if (empty($this->configuration['stores'])) {
      return $this->t('Not restricted');
    }
    $count = count($this->configuration['stores']);
    return $this->t('Visible on @count store(s)', ['@count' => $count]);
  }
}
